@@ -12,8 +12,10 @@ from typing import (
     Generic,
     NamedTuple,
     Optional,
+    Sequence,
     Type,
     TypeVar,
+    Union,
     cast,
 )
 
@@ -52,7 +54,7 @@ class JsonRpcServerMode(Enum):
 
 
 class TcpParams(NamedTuple):
-    host: Optional[str] = None
+    host: Union[str, Sequence[str], None] = None
     port: int = 0
 
 
@@ -201,7 +203,7 @@ class JsonRPCServer(Generic[TProtocol], abc.ABC):
         self._run_func = run_io_nonblocking
 
     @_logger.call
-    async def start_tcp(self, host: Optional[str] = None, port: int = 0) -> None:
+    async def start_tcp(self, host: Union[str, Sequence[str], None] = None, port: int = 0) -> None:
         self.mode = JsonRpcServerMode.TCP
 
         self._server = await self.loop.create_server(self.create_protocol, host, port, reuse_address=True)
