@@ -190,25 +190,17 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
             )
 
     @async_tasking_event_iterator
-    async def collect(sender, document: TextDocument) -> DiagnosticsResult:  # NOSONAR
+    async def collect(sender, document: TextDocument) -> Optional[DiagnosticsResult]:  # NOSONAR
         ...
 
     @async_tasking_event
-    async def load_workspace_documents(sender) -> List[WorkspaceDocumentsResult]:  # NOSONAR
+    async def load_workspace_documents(sender) -> Optional[List[WorkspaceDocumentsResult]]:  # NOSONAR
         ...
 
     @async_tasking_event
     async def on_workspace_loaded(sender) -> None:  # NOSONAR
         ...
 
-    @async_tasking_event
-    async def on_workspace_diagnostics_ended(sender) -> None:  # NOSONAR
-        ...
-
-    @async_tasking_event
-    async def on_document_diagnostics_ended(sender) -> None:  # NOSONAR
-        ...
-
     @async_event
     async def on_get_analysis_progress_mode(sender, uri: Uri) -> Optional[AnalysisProgressMode]:  # NOSONAR
         ...
@@ -370,7 +362,10 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
                     except asyncio.CancelledError:
                         pass
 
-                asyncio.run_coroutine_threadsafe(cancel(task), loop=task.get_loop()).result(5)
+                try:
+                    asyncio.run_coroutine_threadsafe(cancel(task), loop=task.get_loop()).result(600)
+                except TimeoutError as e:
+                    raise RuntimeError("Can't cancel diagnostics task.") from e
 
                 # task.get_loop().call_soon_threadsafe(task.cancel)
 
@@ -405,6 +400,8 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
                 if isinstance(result_any, BaseException):
                     if not isinstance(result_any, asyncio.CancelledError):
                         self._logger.exception(result_any, exc_info=result_any)
+                elif result_any is None:
+                    continue
                 else:
                     result = cast(DiagnosticsResult, result_any)
 
