@@ -487,12 +487,14 @@ class ImportsManager:
         from robot.utils.text import split_args_from_name_or_path
 
         async with self._command_line_variables_lock:
+
             if self._command_line_variables is None:
+                command_line_vars: List[VariableDefinition] = []
 
                 if self.config is None:
                     self._command_line_variables = []
                 else:
-                    self._command_line_variables = [
+                    command_line_vars = [
                         CommandLineVariableDefinition(0, 0, 0, 0, "", f"${{{k}}}", None, has_value=True, value=(v,))
                         for k, v in self.config.variables.items()
                     ]
@@ -503,14 +505,16 @@ class ImportsManager:
                                 name, tuple(args), str(self.folder.to_path()), self
                             )
                             if lib_doc is not None:
-                                self._command_line_variables += lib_doc.variables
+                                command_line_vars += lib_doc.variables
 
                         except (SystemExit, KeyboardInterrupt, asyncio.CancelledError):
                             raise
                         except BaseException as e:
                             self._logger.exception(e)
 
-            return self._command_line_variables
+                self._command_line_variables = command_line_vars
+
+            return self._command_line_variables or []
 
     @async_tasking_event
     async def libraries_changed(sender, libraries: List[LibraryDoc]) -> None:  # NOSONAR
@@ -533,7 +537,6 @@ class ImportsManager:
         await self.imports_changed(self, uri)
 
     @language_id("robotframework")
-    @threaded()
     async def resource_document_changed(self, sender: Any, document: TextDocument) -> None:
         resource_changed: List[LibraryDoc] = []
 
@@ -623,16 +626,19 @@ class ImportsManager:
 
     def __remove_library_entry(self, entry_key: _LibrariesEntryKey, entry: _LibrariesEntry, now: bool = False) -> None:
         async def remove(k: _LibrariesEntryKey, e: _LibrariesEntry) -> None:
-            if len(e.references) == 0 or now:
-                self._logger.debug(lambda: f"Remove Library Entry {k}")
-                async with self._libaries_lock:
-                    if len(e.references) == 0:
-                        e1 = self._libaries.get(k, None)
-                        if e1 == e:
-                            self._libaries.pop(k, None)
+            try:
+                if len(e.references) == 0 or now:
+                    self._logger.debug(lambda: f"Remove Library Entry {k}")
+                    async with self._libaries_lock:
+                        if len(e.references) == 0:
+                            e1 = self._libaries.get(k, None)
+                            if e1 == e:
+                                self._libaries.pop(k, None)
 
-                            await e.invalidate()
-                self._logger.debug(lambda: f"Library Entry {k} removed")
+                                await e.invalidate()
+                    self._logger.debug(lambda: f"Library Entry {k} removed")
+            finally:
+                await self._library_files_cache.clear()
 
         try:
             if asyncio.get_running_loop():
@@ -642,20 +648,24 @@ class ImportsManager:
 
     def __remove_resource_entry(self, entry_key: _ResourcesEntryKey, entry: _ResourcesEntry, now: bool = False) -> None:
         async def remove(k: _ResourcesEntryKey, e: _ResourcesEntry) -> None:
-            if len(e.references) == 0 or now:
-                self._logger.debug(lambda: f"Remove Resource Entry {k}")
-                async with self._resources_lock:
-                    if len(e.references) == 0:
-                        e1 = self._resources.get(k, None)
-                        if e1 == e:
-                            self._resources.pop(k, None)
+            try:
+                if len(e.references) == 0 or now:
+                    self._logger.debug(lambda: f"Remove Resource Entry {k}")
+                    async with self._resources_lock:
+                        if len(e.references) == 0 or now:
+                            e1 = self._resources.get(k, None)
+                            if e1 == e:
+                                self._resources.pop(k, None)
 
-                            await e.invalidate()
-                self._logger.debug(lambda: f"Resource Entry {k} removed")
+                                await e.invalidate()
+                    self._logger.debug(lambda: f"Resource Entry {k} removed")
+            finally:
+                await self._resource_files_cache.clear()
 
         try:
             if asyncio.get_running_loop():
                 create_sub_task(remove(entry_key, entry))
+
         except RuntimeError:
             pass
 
@@ -663,16 +673,19 @@ class ImportsManager:
         self, entry_key: _VariablesEntryKey, entry: _VariablesEntry, now: bool = False
     ) -> None:
         async def remove(k: _VariablesEntryKey, e: _VariablesEntry) -> None:
-            if len(e.references) == 0 or now:
-                self._logger.debug(lambda: f"Remove Variables Entry {k}")
-                async with self._variables_lock:
-                    if len(e.references) == 0:
-                        e1 = self._variables.get(k, None)
-                        if e1 == e:
-                            self._variables.pop(k, None)
+            try:
+                if len(e.references) == 0 or now:
+                    self._logger.debug(lambda: f"Remove Variables Entry {k}")
+                    async with self._variables_lock:
+                        if len(e.references) == 0:
+                            e1 = self._variables.get(k, None)
+                            if e1 == e:
+                                self._variables.pop(k, None)
 
-                            await e.invalidate()
-                self._logger.debug(lambda: f"Variables Entry {k} removed")
+                                await e.invalidate()
+                    self._logger.debug(lambda: f"Variables Entry {k} removed")
+            finally:
+                await self._variables_files_cache.clear()
 
         try:
             if asyncio.get_running_loop():
