@@ -31,9 +31,9 @@ class RobotCodeLensProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixi
         self._running_task: Set[Tuple[TextDocument, KeywordDoc]] = set()
 
         parent.diagnostics.on_workspace_loaded.add(self.codelens_refresh)
-        parent.diagnostics.on_document_diagnostics_ended.add(self.codelens_refresh)
-        parent.diagnostics.on_workspace_diagnostics_ended.add(self.codelens_refresh)
+        parent.robot_references.cache_cleared.add(self.codelens_refresh)
 
+    @language_id("robotframework")
     async def codelens_refresh(self, sender: Any) -> None:  # NOSONAR
         await self.parent.code_lens.refresh()
 
@@ -126,13 +126,6 @@ class RobotCodeLensProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixi
                         if document is None or kw_doc is None:
                             return
 
-                        # await run_coroutine_in_thread(
-                        #     self.parent.robot_references.find_keyword_references,
-                        #     document,
-                        #     kw_doc,
-                        #     include_declaration=False,
-                        # )
-
                         await self.parent.robot_references.find_keyword_references(
                             document, kw_doc, include_declaration=False
                         )
@@ -141,7 +134,7 @@ class RobotCodeLensProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixi
 
                     key = (document, kw_doc)
                     if key not in self._running_task:
-                        task = create_sub_task(find_refs(), loop=self.parent.loop)
+                        task = create_sub_task(find_refs(), loop=self.parent.diagnostics.diagnostics_loop)
 
                         def done(task: Any) -> None:
                             self._running_task.remove(key)
