@@ -51,7 +51,6 @@ from ..utils import async_ast
 from ..utils.ast_utils import (
     HasTokens,
     Token,
-    is_not_variable_token,
     iter_over_keyword_names_and_owners,
     token_in_range,
 )
@@ -82,6 +81,7 @@ class RobotSemTokenTypes(Enum):
     KEYWORD_NAME = "keywordName"
     CONTROL_FLOW = "controlFlow"
     ARGUMENT = "argument"
+    EMBEDDED_ARGUMENT = "embeddedArgument"
     VARIABLE = "variable"
     KEYWORD = "keywordCall"
     KEYWORD_INNER = "keywordCallInner"
@@ -325,8 +325,8 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
                 for g in cls.ESCAPE_REGEX.finditer(token.value):
                     yield SemTokenInfo.from_token(
                         token,
-                        sem_info[0] if g.group("x") is None or g.end() - g.start() == 1 else RobotSemTokenTypes.ESCAPE,
-                        sem_info[1],
+                        sem_type if g.group("x") is None or g.end() - g.start() == 1 else RobotSemTokenTypes.ESCAPE,
+                        sem_mod,
                         col_offset + g.start(),
                         g.end() - g.start(),
                     )
@@ -400,18 +400,48 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
                         1,
                         SemanticTokenTypes.OPERATOR,
                     )
-                # if builtin_library_doc is not None and KeywordMatcher(kw) in builtin_library_doc.keywords:
-                #     doc = await namespace.find_keyword(token.value)
-                #     if (
-                #         doc is not None
-                #         and doc.libname == cls.BUILTIN_MATCHER
-                #         and KeywordMatcher(doc.name) == KeywordMatcher(kw)
-                #     ):
-                #         if not sem_mod:
-                #             sem_mod = set()
-                #         sem_mod.add(RobotSemTokenModifiers.BUILTIN)
 
-                yield SemTokenInfo.from_token(token, sem_type, sem_mod, col_offset + kw_index, len(kw))
+                if builtin_library_doc is not None and kw in builtin_library_doc.keywords:
+                    doc = await namespace.find_keyword(token.value)
+                    if (
+                        doc is not None
+                        and doc.libname == cls.BUILTIN_MATCHER
+                        and KeywordMatcher(doc.name) == KeywordMatcher(kw)
+                    ):
+                        if not sem_mod:
+                            sem_mod = set()
+                        sem_mod.add(RobotSemTokenModifiers.BUILTIN)
+
+                kw_doc = await namespace.find_keyword(token.value, raise_keyword_error=False)
+                if kw_doc is not None and kw_doc.is_embedded:
+                    if get_robot_version() >= (6, 0):
+                        m = kw_doc.matcher.embedded_arguments.match(kw)
+                    else:
+                        m = kw_doc.matcher.embedded_arguments.name.match(kw)
+
+                    if m and m.lastindex is not None:
+                        start, end = m.span(0)
+                        for i in range(1, m.lastindex + 1):
+                            arg_start, arg_end = m.span(i)
+                            yield SemTokenInfo.from_token(
+                                token, sem_type, sem_mod, col_offset + kw_index + start, arg_start - start
+                            )
+                            yield SemTokenInfo.from_token(
+                                token,
+                                RobotSemTokenTypes.EMBEDDED_ARGUMENT,
+                                sem_mod,
+                                col_offset + kw_index + arg_start,
+                                arg_end - arg_start,
+                            )
+                            start = arg_end + 1
+
+                        if start < end:
+                            yield SemTokenInfo.from_token(
+                                token, sem_type, sem_mod, col_offset + kw_index + start, end - start
+                            )
+
+                else:
+                    yield SemTokenInfo.from_token(token, sem_type, sem_mod, col_offset + kw_index, len(kw))
             elif token.type == RobotToken.NAME and isinstance(node, (LibraryImport, ResourceImport, VariablesImport)):
                 yield SemTokenInfo.from_token(token, RobotSemTokenTypes.NAMESPACE, sem_mod, col_offset, length)
             elif get_robot_version() >= (5, 0) and token.type == RobotToken.OPTION:
@@ -461,14 +491,30 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
         resources_matchers: Dict[KeywordMatcher, ResourceEntry],
     ) -> AsyncGenerator[SemTokenInfo, None]:
         from robot.parsing.lexer.tokens import Token as RobotToken
+        from robot.parsing.model.statements import Variable
+        from robot.utils.escaping import split_from_equals
 
-        if token.type in {*RobotToken.ALLOW_VARIABLES, RobotToken.KEYWORD, ROBOT_KEYWORD_INNER}:
+        if token.type in {RobotToken.ARGUMENT, RobotToken.TESTCASE_NAME, RobotToken.KEYWORD_NAME}:
+
+            if isinstance(node, Variable) and token.type == RobotToken.ARGUMENT and node.name and node.name[0] == "&":
+                name, value = split_from_equals(token.value)
+                if value is not None:
+                    length = len(name)
+
+                    yield SemTokenInfo.from_token(
+                        RobotToken(ROBOT_NAMED_ARGUMENT, name, token.lineno, token.col_offset),
+                        RobotSemTokenTypes.NAMED_ARGUMENT,
+                    )
+                    yield SemTokenInfo.from_token(
+                        RobotToken(ROBOT_OPERATOR, "=", token.lineno, token.col_offset + length),
+                        SemanticTokenTypes.OPERATOR,
+                    )
+                    token = RobotToken(token.type, value, token.lineno, token.col_offset + length + 1, token.error)
 
             for sub_token in self._tokenize_variables(
                 token,
                 ignore_errors=True,
                 identifiers="$" if token.type == RobotToken.KEYWORD_NAME else "$@&%",
-                extra_types={ROBOT_KEYWORD_INNER},
             ):
                 async for e in self.generate_sem_sub_tokens(
                     namespace, builtin_library_doc, libraries_matchers, resources_matchers, sub_token, node
@@ -515,7 +561,7 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
                     builtin_library_doc,
                     libraries_matchers,
                     resources_matchers,
-                    await namespace.find_keyword(unescape(token.value)) if is_not_variable_token(token) else None,
+                    await namespace.find_keyword(unescape(token.value), raise_keyword_error=False),
                     RobotToken(ROBOT_KEYWORD_INNER, token.value, token.lineno, token.col_offset, token.error),
                     arguments[1:],
                     node,
@@ -537,7 +583,7 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
                         builtin_library_doc,
                         libraries_matchers,
                         resources_matchers,
-                        await namespace.find_keyword(unescape(token.value)) if is_not_variable_token(token) else None,
+                        await namespace.find_keyword(unescape(token.value), raise_keyword_error=False),
                         RobotToken(ROBOT_KEYWORD_INNER, token.value, token.lineno, token.col_offset, token.error),
                         arguments[1:],
                         node,
@@ -577,7 +623,7 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
                         builtin_library_doc,
                         libraries_matchers,
                         resources_matchers,
-                        await namespace.find_keyword(unescape(token.value)) if is_not_variable_token(token) else None,
+                        await namespace.find_keyword(unescape(token.value), raise_keyword_error=False),
                         RobotToken(ROBOT_KEYWORD_INNER, token.value, token.lineno, token.col_offset, token.error),
                         args,
                         node,
@@ -617,11 +663,7 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
                                 arguments = arguments[1:]
                             continue
 
-                        inner_kw_doc = (
-                            await namespace.find_keyword(unescape(token.value))
-                            if is_not_variable_token(token)
-                            else None
-                        )
+                        inner_kw_doc = await namespace.find_keyword(unescape(token.value), raise_keyword_error=False)
 
                         if inner_kw_doc is not None and inner_kw_doc.is_run_keyword_if():
                             yield RobotToken(
