@@ -11,7 +11,6 @@ import warnings
 import weakref
 from collections import deque
 from concurrent.futures.thread import ThreadPoolExecutor
-from contextlib import asynccontextmanager
 from types import TracebackType
 from typing import (
     Any,
@@ -283,6 +282,9 @@ def check_canceled_sync() -> bool:
     return True
 
 
+# __executor = ThreadPoolExecutor(thread_name_prefix="global_sub_asyncio")
+
+
 def run_in_thread(func: Callable[..., _T], /, *args: Any, **kwargs: Any) -> asyncio.Future[_T]:
     global __tread_pool_executor
 
@@ -291,6 +293,11 @@ def run_in_thread(func: Callable[..., _T], /, *args: Any, **kwargs: Any) -> asyn
     ctx = contextvars.copy_context()
     func_call = functools.partial(ctx.run, func, *args, **kwargs)
 
+    # return cast(
+    #     "asyncio.Future[_T]",
+    #     loop.run_in_executor(__executor, cast(Callable[..., _T], func_call)),
+    # )
+
     executor = ThreadPoolExecutor(max_workers=1, thread_name_prefix="sub_asyncio")
     try:
         return cast(
@@ -372,8 +379,8 @@ class Event:
         return f"<{res[1:-1]} [{extra}]>"
 
     def is_set(self) -> bool:
-        # with self._lock:
-        return self._value
+        with self._lock:
+            return self._value
 
     def set(self) -> None:
         with self._lock:
@@ -396,20 +403,19 @@ class Event:
                                 finally:
                                     ev.set()
 
-                            if not fut.done():
-                                done = threading.Event()
+                            done = threading.Event()
 
-                                fut.get_loop().call_soon_threadsafe(set_result, fut, done)
+                            fut.get_loop().call_soon_threadsafe(set_result, fut, done)
 
-                                start = time.monotonic()
-                                while not done.is_set():
-                                    check_canceled_sync()
+                            start = time.monotonic()
+                            while not done.is_set():
+                                check_canceled_sync()
 
-                                    if time.monotonic() - start > 120:
-                                        warnings.warn("Can't set future result.")
-                                        break
+                                if time.monotonic() - start > 120:
+                                    warnings.warn("Can't set future result.")
+                                    break
 
-                                    time.sleep(0.001)
+                                time.sleep(0.001)
 
     def clear(self) -> None:
         with self._lock:
@@ -436,7 +442,7 @@ class Lock:
     def __init__(self) -> None:
         self._waiters: Optional[Deque[asyncio.Future[Any]]] = None
         self._locked = False
-        self._lock = threading.Lock()
+        self._lock = threading.RLock()
 
     async def __aenter__(self) -> None:
         await self.acquire()
@@ -444,7 +450,7 @@ class Lock:
     async def __aexit__(
         self, exc_type: Optional[Type[BaseException]], exc_val: Optional[BaseException], exc_tb: Optional[TracebackType]
     ) -> None:
-        await self.release()
+        self.release()
 
     def __repr__(self) -> str:
         res = super().__repr__()
@@ -453,22 +459,12 @@ class Lock:
             extra = f"{extra}, waiters:{len(self._waiters)}"
         return f"<{res[1:-1]} [{extra}]>"
 
-    @asynccontextmanager
-    async def __inner_lock(self) -> AsyncGenerator[Any, None]:
-        while not (b := self._lock.acquire(blocking=False)):
-            await asyncio.sleep(0.001)
-        try:
-            yield None
-        finally:
-            if b:
-                self._lock.release()
-
     @property
     def locked(self) -> bool:
         return self._locked
 
     async def acquire(self) -> bool:
-        async with self.__inner_lock():
+        with self._lock:
             if not self._locked and (self._waiters is None or all(w.cancelled() for w in self._waiters)):
                 self._locked = True
                 return True
@@ -480,35 +476,49 @@ class Lock:
             self._waiters.append(fut)
 
         try:
-            # await asyncio.wait_for(fut, 120)
-            await fut
-        finally:
-            async with self.__inner_lock():
-                if fut in self._waiters:
+            try:
+
+                def aaa() -> None:
+                    warnings.warn(f"Lock takes to long {threading.current_thread()}")
+
+                h = fut.get_loop().call_later(120, aaa)
+
+                await fut
+
+                h.cancel()
+            finally:
+                with self._lock:
                     self._waiters.remove(fut)
-                self._locked = True
+        except asyncio.CancelledError:
+            with self._lock:
+                if not self._locked:
+                    self._wake_up_first()
+                raise
+
+        with self._lock:
+            self._locked = True
 
         return True
 
-    async def release(self) -> None:
-        async with self.__inner_lock():
-            if self._waiters is None or len(self._waiters) == 0:
-                if self._locked:
-                    self._locked = False
+    def release(self) -> None:
+        with self._lock:
+            wake_up = False
+            if self._locked:
+                self._locked = False
+                wake_up = True
 
-        await self._wake_up_next()
+        if wake_up:
+            self._wake_up_first()
 
-    async def _wake_up_next(self) -> None:
+    def _wake_up_first(self) -> None:
         if not self._waiters:
             return
 
-        async with self.__inner_lock():
+        with self._lock:
             try:
                 fut = next(iter(self._waiters))
             except StopIteration:
                 return
-            if fut in self._waiters:
-                self._waiters.remove(fut)
 
         if fut.get_loop().is_running() and not fut.get_loop().is_closed():
             if fut.get_loop() == asyncio.get_running_loop():
@@ -535,10 +545,12 @@ class Lock:
                             warnings.warn("Can't set future result.")
                             break
 
-                        await asyncio.sleep(0.001)
+                        time.sleep(0.001)
         else:
             warnings.warn(f"Future {repr(fut)} loop is closed")
-            await self._wake_up_next()
+            with self._lock:
+                self._waiters.remove(fut)
+            self._wake_up_first()
 
 
 class FutureInfo:
@@ -636,39 +648,6 @@ def create_sub_future(loop: Optional[asyncio.AbstractEventLoop] = None) -> async
     return result
 
 
-class _FutureHolder(Generic[_T]):
-    def __init__(self, cfuture: concurrent.futures.Future[_T]):
-        self.cfuture = cfuture
-        self.afuture = wrap_sub_future(cfuture)
-
-
-def spawn_coroutine_from_thread(
-    func: Callable[..., Coroutine[Any, Any, _T]],
-    *args: Any,
-    loop: Optional[asyncio.AbstractEventLoop] = None,
-    **kwargs: Any,
-) -> concurrent.futures.Future[_T]:
-    if loop is None:
-        loop = asyncio.get_running_loop()
-
-    result = _FutureHolder(asyncio.run_coroutine_threadsafe(func(*args), loop))
-    return result.cfuture
-
-
-def run_coroutine_from_thread(
-    func: Callable[..., Coroutine[Any, Any, _T]],
-    *args: Any,
-    loop: Optional[asyncio.AbstractEventLoop] = None,
-    **kwargs: Any,
-) -> _T:
-    if loop is None:
-        loop = asyncio.get_running_loop()
-
-    result = _FutureHolder(asyncio.run_coroutine_threadsafe(func(*args), loop))
-
-    return result.cfuture.result()
-
-
 def run_coroutine_from_thread_as_future(
     func: Callable[..., Coroutine[Any, Any, _T]],
     *args: Any,
